==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/PasswordImportResponseCommandsInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordImportResponseCommandsInnerValue;
import org.openapitools.jackson.nullable.JsonNullable;
import com.fasterxml.jackson.annotation.JsonIgnore;
import org.openapitools.jackson.nullable.JsonNullable;
import java.util.NoSuchElementException;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordImportResponseCommandsInner
 */
@JsonPropertyOrder({ PasswordImportResponseCommandsInner.JSON_PROPERTY_TYPE,
        PasswordImportResponseCommandsInner.JSON_PROPERTY_VALUE })
@JsonTypeName("PasswordImportResponse_commands_inner")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordImportResponseCommandsInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TYPE = "type";
    private JsonNullable<Object> type = JsonNullable.<Object> of(null);

    public static final String JSON_PROPERTY_VALUE = "value";
    private PasswordImportResponseCommandsInnerValue value;

    public PasswordImportResponseCommandsInner() {
    }

    public PasswordImportResponseCommandsInner type(Object type) {
        this.type = JsonNullable.<Object> of(type);

        return this;
    }

    /**
     * The location where you specify the command. For the password import inline hook, there&#39;s only one command,
     * &#x60;com.okta.action.update&#x60;.
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The location where you specify the command. For the password import inline hook, there's only one command, `com.okta.action.update`.")
    @JsonIgnore

    public Object getType() {
        return type.orElse(null);
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public JsonNullable<Object> getType_JsonNullable() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    public void setType_JsonNullable(JsonNullable<Object> type) {
        this.type = type;
    }

    public void setType(Object type) {
        this.type = JsonNullable.<Object> of(type);
    }

    public PasswordImportResponseCommandsInner value(PasswordImportResponseCommandsInnerValue value) {

        this.value = value;
        return this;
    }

    /**
     * Get value
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordImportResponseCommandsInnerValue getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(PasswordImportResponseCommandsInnerValue value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordImportResponseCommandsInner passwordImportResponseCommandsInner = (PasswordImportResponseCommandsInner) o;
        return equalsNullable(this.type, passwordImportResponseCommandsInner.type)
                && Objects.equals(this.value, passwordImportResponseCommandsInner.value);
        // ;
    }

    private static <T> boolean equalsNullable(JsonNullable<T> a, JsonNullable<T> b) {
        return a == b
                || (a != null && b != null && a.isPresent() && b.isPresent() && Objects.deepEquals(a.get(), b.get()));
    }

    @Override
    public int hashCode() {
        return Objects.hash(hashCodeNullable(type), value);
    }

    private static <T> int hashCodeNullable(JsonNullable<T> a) {
        if (a == null) {
            return 1;
        }
        return a.isPresent() ? Arrays.deepHashCode(new Object[] { a.get() }) : 31;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordImportResponseCommandsInner {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/PasswordImportResponseCommandsInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordImportResponseCommandsInnerValue;
import org.openapitools.jackson.nullable.JsonNullable;
import com.fasterxml.jackson.annotation.JsonIgnore;
import org.openapitools.jackson.nullable.JsonNullable;
import java.util.NoSuchElementException;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordImportResponseCommandsInner
 */
@JsonPropertyOrder({ PasswordImportResponseCommandsInner.JSON_PROPERTY_TYPE,
        PasswordImportResponseCommandsInner.JSON_PROPERTY_VALUE })
@JsonTypeName("PasswordImportResponse_commands_inner")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PasswordImportResponseCommandsInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TYPE = "type";
    private JsonNullable<Object> type = JsonNullable.<Object> of(null);

    public static final String JSON_PROPERTY_VALUE = "value";
    private PasswordImportResponseCommandsInnerValue value;

    public PasswordImportResponseCommandsInner() {
    }

    public PasswordImportResponseCommandsInner type(Object type) {
        this.type = JsonNullable.<Object> of(type);

        return this;
    }

    /**
     * The location where you specify the command. For the password import inline hook, there&#39;s only one command,
     * &#x60;com.okta.action.update&#x60;.
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The location where you specify the command. For the password import inline hook, there's only one command, `com.okta.action.update`.")
    @JsonIgnore

    public Object getType() {
        return type.orElse(null);
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public JsonNullable<Object> getType_JsonNullable() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    public void setType_JsonNullable(JsonNullable<Object> type) {
        this.type = type;
    }

    public void setType(Object type) {
        this.type = JsonNullable.<Object> of(type);
    }

    public PasswordImportResponseCommandsInner value(PasswordImportResponseCommandsInnerValue value) {

        this.value = value;
        return this;
    }

    /**
     * Get value
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordImportResponseCommandsInnerValue getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(PasswordImportResponseCommandsInnerValue value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordImportResponseCommandsInner passwordImportResponseCommandsInner = (PasswordImportResponseCommandsInner) o;
        return equalsNullable(this.type, passwordImportResponseCommandsInner.type)
                && Objects.equals(this.value, passwordImportResponseCommandsInner.value);
        // ;
    }

    private static <T> boolean equalsNullable(JsonNullable<T> a, JsonNullable<T> b) {
        return a == b
                || (a != null && b != null && a.isPresent() && b.isPresent() && Objects.deepEquals(a.get(), b.get()));
    }

    @Override
    public int hashCode() {
        return Objects.hash(hashCodeNullable(type), value);
    }

    private static <T> int hashCodeNullable(JsonNullable<T> a) {
        if (a == null) {
            return 1;
        }
        return a.isPresent() ? Arrays.deepHashCode(new Object[] { a.get() }) : 31;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordImportResponseCommandsInner {\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
